@@ -67,11 +67,11 @@ newtype Reverse a = Reverse { unReverse :: a }
 --   Primitives kinds (see 'primitive') are not tagged with a version
 --   id and hence cannot be extended later.
 --
---   Extensions (see 'extension') tells the system that there exists
+--   Extensions (see 'extension') tell the system that there exists
 --   a previous version of the data type which should be migrated if
 --   needed.
 --
---   There is also a default kind which is neither primitive nor is
+--   There is also a default kind which is neither primitive nor
 --   an extension of a previous type.
 data Kind a where
     Primitive :: Kind a
@@ -93,7 +93,7 @@ newtype Prim a = Prim { getPrimitive :: a }
 --   even though 'getCopy' and 'putCopy' can't be used directly.
 --   To serialize/parse a data type using 'SafeCopy', see 'safeGet'
 --   and 'safePut'.
-class SafeCopy a where
+class Typeable a => SafeCopy a where
     -- | The version of the type.
     --
     --   Only used as a key so it must be unique (this is checked at run-time)
@@ -117,7 +117,7 @@ class SafeCopy a where
 
     -- | This method defines how a value should be parsed without worrying about
     --   previous versions or migrations. This function cannot be used directly.
-    --   One should use 'safeGet', instead.
+    --   One should use 'safePut, instead.
     putCopy  :: a -> Contained Put
 
     -- | Internal function that should not be overrided.
@@ -162,7 +162,8 @@ instance (GPutCopy f p, GPutCopy g p) => GPutCopy (f :+: g) p where
     {-# INLINE gputCopy #-}
 
 -- | A constraint that combines 'SafeCopy' and 'Typeable'.
-type SafeCopy' a = (SafeCopy a, Typeable a)
+type SafeCopy' a = SafeCopy a
+{-# DEPRECATED SafeCopy' "SafeCopy' is now equivalent to SafeCopy " #-}
 
 -- To get the current safecopy behavior we need to emulate the
 -- template haskell code here - collect the (a -> Put) values for all
@@ -191,7 +192,7 @@ instance GPutFields f p => GPutFields (M1 S c f) p where
     gputFields p (M1 a) = gputFields p a
     {-# INLINE gputFields #-}
 
-instance SafeCopy' a => GPutFields (K1 R a) p where
+instance SafeCopy a => GPutFields (K1 R a) p where
     gputFields _ (K1 a) = do
       getSafePutGeneric putCopy a
     {-# INLINE gputFields #-}
@@ -265,7 +266,7 @@ instance GGetFields f p => GGetFields (M1 S c f) p where
       return (M1 <$> getter)
     {-# INLINE ggetFields #-}
 
-instance SafeCopy' a => GGetFields (K1 R a) p where
+instance SafeCopy a => GGetFields (K1 R a) p where
     ggetFields _ = do
       getter <- getSafeGetGeneric
       return (K1 <$> getter)
@@ -287,9 +288,9 @@ data DatatypeInfo =
 -- | Whereas the other 'getSafeGet' is only run when we know we need a
 -- version, this one is run for every field and must decide whether to
 -- read a version or not.  It constructs a Map TypeRep Int32 and reads
--- whent he new TypeRep is not in the map.
+-- when the new TypeRep is not in the map.
 getSafeGetGeneric ::
-  forall a. SafeCopy' a
+  forall a. SafeCopy a
   => StateT (Map TypeRep Int32) Get (Get a)
 getSafeGetGeneric
     = checkConsistency proxy $
@@ -308,7 +309,7 @@ getSafeGetGeneric
 -- type prevents doing this because each fields may have a different
 -- type.  Maybe you can show me a better way
 getSafePutGeneric ::
-  forall a. SafeCopy' a
+  forall a. SafeCopy a
   => (a -> Contained Put)
   -> a
   -> RWST () [Put] (Set TypeRep) PutM ()
@@ -324,7 +325,7 @@ getSafePutGeneric cput a
                         tell [unsafeUnPack (cput $ asProxyType a proxy)]
     where proxy = Proxy :: Proxy a
 
-type GSafeCopy a = (SafeCopy' a, Generic a, GPutCopy (Rep a) DatatypeInfo, Constructors a)
+type GSafeCopy a = (SafeCopy a, Generic a, GPutCopy (Rep a) DatatypeInfo, Constructors a)
 
 -- | Generic only version of safePut. Instead of calling 'putCopy' it
 -- calls 'putCopyDefault', a copy of the implementation of the
@@ -474,7 +475,7 @@ instance Serialize (Version a) where
 -- parsers/putters.
 
 -- | To ensure that no-one reads or writes values without handling versions
---   correct, it is necessary to restrict access to 'getCopy' and 'putCopy'.
+--   correctly, it is necessary to restrict access to 'getCopy' and 'putCopy'.
 --   This is where 'Contained' enters the picture. It allows you to put
 --   values in to a container but not to take them out again.
 newtype Contained a = Contained {unsafeUnPack :: a}
@@ -547,7 +548,7 @@ checkConsistency proxy ks
         Consistent        -> ks
 
 -- | PutM doesn't have reasonable 'fail' implementation.
--- It just throws unpure exception anyway.
+-- It just throws an unpure exception anyway.
 unpureCheckConsistency :: SafeCopy a => Proxy a -> b -> b
 unpureCheckConsistency proxy ks
     = case consistentFromProxy proxy of
@@ -555,14 +556,14 @@ unpureCheckConsistency proxy ks
         Consistent        -> ks
 
 {-# INLINE computeConsistency #-}
-computeConsistency :: SafeCopy a => Proxy a -> Consistency a
+computeConsistency :: forall a. SafeCopy a => Proxy a -> Consistency a
 computeConsistency proxy
     -- Match a few common cases before falling through to the general case.
     -- This allows use to generate nearly all consistencies at compile-time.
     | isObviouslyConsistent (kindFromProxy proxy)
     = Consistent
     | versions /= nub versions
-    = NotConsistent $ "Duplicate version tags: " ++ show versions
+    = NotConsistent $ "Duplicate version tags for " ++ show (typeRep (Proxy @a)) ++ ": " ++ show versions
     | not (validChain proxy)
     = NotConsistent "Primitive types cannot be extended as they have no version tag."
     | otherwise
